@@ -11,12 +11,10 @@ import pytest
 import spatialdata as sd
 import spatialdata_plot  # noqa: F401
 from anndata import AnnData
+from datatree import DataTree
 from geopandas import GeoDataFrame
 from matplotlib.testing.compare import compare_images
-from multiscale_spatial_image import MultiscaleSpatialImage
-from numpy.random import default_rng
 from shapely.geometry import MultiPolygon, Polygon
-from spatial_image import SpatialImage
 from spatialdata import SpatialData
 from spatialdata.datasets import blobs, raccoon
 from spatialdata.models import (
@@ -35,9 +33,9 @@ HERE: Path = Path(__file__).parent
 EXPECTED = HERE / "_images"
 ACTUAL = HERE / "figures"
 TOL = 60
-DPI = 40
+DPI = 80
 
-RNG = default_rng()
+RNG = np.random.default_rng(seed=42)
 
 
 @pytest.fixture()
@@ -56,6 +54,11 @@ def sdata_blobs() -> SpatialData:
     return blobs()
 
 
+@pytest.fixture()
+def sdata_blobs_str() -> SpatialData:
+    return blobs(n_channels=5, c_coords=["c1", "c2", "c3", "c4", "c5"])
+
+
 @pytest.fixture()
 def sdata_raccoon() -> SpatialData:
     return raccoon()
@@ -213,7 +216,7 @@ def sdata(request) -> SpatialData:
     return s
 
 
-def _get_images() -> dict[str, Union[SpatialImage, MultiscaleSpatialImage]]:
+def _get_images() -> dict[str, Union[DataArray, DataTree]]:
     out = {}
     dims_2d = ("c", "y", "x")
     dims_3d = ("z", "y", "x", "c")
@@ -240,7 +243,7 @@ def _get_images() -> dict[str, Union[SpatialImage, MultiscaleSpatialImage]]:
     return out
 
 
-def _get_labels() -> dict[str, Union[SpatialImage, MultiscaleSpatialImage]]:
+def _get_labels() -> dict[str, Union[DataArray, DataTree]]:
     out = {}
     dims_2d = ("y", "x")
     dims_3d = ("z", "y", "x")
@@ -375,12 +378,19 @@ class PlotTester(ABC):  # noqa: B024
         ACTUAL.mkdir(parents=True, exist_ok=True)
         out_path = ACTUAL / f"{basename}.png"
 
+        width, height = 400, 300  # fixed dimensions so runners don't change
+        fig = plt.gcf()
+        fig.set_size_inches(width / DPI, height / DPI)
+        fig.set_dpi(DPI)
+
+        # Apply constrained layout and save the plot
+        fig.set_constrained_layout(True)
         plt.savefig(out_path, dpi=DPI)
         plt.close()
 
         if tolerance is None:
             # see https://github.com/scverse/squidpy/pull/302
-            tolerance = 2 * TOL if "Napari" in str(basename) else TOL
+            tolerance = 2 * TOL if "Napari" in basename else TOL
 
         res = compare_images(str(EXPECTED / f"{basename}.png"), str(out_path), tolerance)
 
