@@ -3,6 +3,8 @@ import matplotlib
 import numpy as np
 import scanpy as sc
 import spatialdata_plot  # noqa: F401
+from matplotlib import pyplot as plt
+from matplotlib.colors import Normalize
 from spatial_image import to_spatial_image
 from spatialdata import SpatialData
 
@@ -68,6 +70,17 @@ class TestImages(PlotTester, metaclass=PlotTesterMeta):
     def test_plot_can_render_two_channels_str_from_multiscale_image(self, sdata_blobs_str: SpatialData):
         sdata_blobs_str.pl.render_images(element="blobs_multiscale_image", channel=["c1", "c2"]).pl.show()
 
+    def test_plot_can_pass_vmin_vmax(self, sdata_blobs: SpatialData):
+        fig, axs = plt.subplots(ncols=2, figsize=(6, 3))
+        sdata_blobs.pl.render_images(element="blobs_image", channel=1).pl.show(ax=axs[0])
+        sdata_blobs.pl.render_images(element="blobs_image", channel=1, vmin=0, vmax=0.4).pl.show(ax=axs[1])
+
+    def test_plot_can_pass_normalize(self, sdata_blobs: SpatialData):
+        fig, axs = plt.subplots(ncols=2, figsize=(6, 3))
+        norm = Normalize(vmin=0, vmax=0.4, clip=True)
+        sdata_blobs.pl.render_images(element="blobs_image", channel=1).pl.show(ax=axs[0])
+        sdata_blobs.pl.render_images(element="blobs_image", channel=1, norm=norm).pl.show(ax=axs[1])
+
     def test_plot_can_pass_color_to_single_channel(self, sdata_blobs: SpatialData):
         sdata_blobs.pl.render_images(element="blobs_image", channel=1, palette="red").pl.show()
 
@@ -119,3 +132,6 @@ class TestImages(PlotTester, metaclass=PlotTesterMeta):
             .pl.render_images(element="blobs_image", channel=1, palette="blue", alpha=0.5)
             .pl.show()
         )
+
+    def test_plot_can_stick_to_zorder(self, sdata_blobs: SpatialData):
+        sdata_blobs.pl.render_shapes().pl.render_images().pl.show()
