@@ -111,15 +111,14 @@ class TestLabels(PlotTester, metaclass=PlotTesterMeta):
         self._make_tablemodel_with_categorical_labels(sdata_blobs, label)
 
     def _make_tablemodel_with_categorical_labels(self, sdata_blobs, label):
+
         n_obs = max(get_element_instances(sdata_blobs[label]))
-        adata = AnnData(
-            RNG.normal(size=(n_obs, 10)),
-            obs=pd.DataFrame(RNG.normal(size=(n_obs, 3)), columns=["a", "b", "c"]),
-        )
-        adata.obs["instance_id"] = np.arange(adata.n_obs)
-        adata.obs["category"] = RNG.choice(["a", "b", "c"], size=adata.n_obs)
-        adata.obs["category"][:3] = ["a", "b", "c"]
-        adata.obs["instance_id"] = list(range(adata.n_obs))
+        vals = np.arange(n_obs)
+        obs = pd.DataFrame({"a": vals, "b": vals + 0.3, "c": vals + 0.7})
+
+        adata = AnnData(vals.reshape(-1, 1), obs=obs)
+        adata.obs["instance_id"] = vals
+        adata.obs["category"] = list(["a", "b", "c"] * ((n_obs // 3) + 1))[:n_obs]
         adata.obs["region"] = label
         table = TableModel.parse(
             adata=adata,
