@@ -1,12 +1,14 @@
 import matplotlib
+import numpy as np
 import scanpy as sc
 import spatialdata_plot  # noqa: F401
 from spatialdata import SpatialData
 
-from tests.conftest import PlotTester, PlotTesterMeta
+from tests.conftest import DPI, PlotTester, PlotTesterMeta
 
+RNG = np.random.default_rng(seed=42)
 sc.pl.set_rcParams_defaults()
-sc.set_figure_params(dpi=40, color_map="viridis")
+sc.set_figure_params(dpi=DPI, color_map="viridis")
 matplotlib.use("agg")  # same as GitHub action runner
 _ = spatialdata_plot
 
@@ -20,4 +22,4 @@ _ = spatialdata_plot
 
 class TestShow(PlotTester, metaclass=PlotTesterMeta):
     def test_plot_pad_extent_adds_padding(self, sdata_blobs: SpatialData):
-        sdata_blobs.pl.render_images(elements="blobs_image").pl.show(pad_extent=100)
+        sdata_blobs.pl.render_images(element="blobs_image").pl.show(pad_extent=100)
